@@ -150,3 +150,63 @@ class CollectionError(PrivateError):
 
 class CollectionNotFound(CollectionError):
     pass
+
+
+class DirectError(PrivateError):
+    pass
+
+
+class DirectThreadNotFound(DirectError):
+    pass
+
+
+class DirectMessageNotFound(DirectError):
+    pass
+
+
+class VideoNotDownload(PrivateError):
+    pass
+
+
+class VideoNotUpload(PrivateError):
+    pass
+
+
+class VideoConfigureError(VideoNotUpload):
+    pass
+
+
+class VideoConfigureStoryError(VideoConfigureError):
+    pass
+
+
+class PhotoNotUpload(PrivateError):
+    pass
+
+
+class PhotoConfigureError(PhotoNotUpload):
+    pass
+
+
+class PhotoConfigureStoryError(PhotoConfigureError):
+    pass
+
+
+class IGTVNotUpload(PrivateError):
+    pass
+
+
+class IGTVConfigureError(IGTVNotUpload):
+    pass
+
+
+class AlbumNotDownload(PrivateError):
+    pass
+
+
+class UnknownFormat(PrivateError):
+    pass
+
+
+class AlbumConfigureError(PrivateError):
+    pass
